Index: src/gpu/effects/GrConvexPolyEffect.h |
diff --git a/src/gpu/effects/GrConvexPolyEffect.h b/src/gpu/effects/GrConvexPolyEffect.h |
index 035d9e95dda03c4a5e3f014399625f8788fcfd2b..225e729242a339a22094080cb7f61a4ea0043977 100644 |
--- a/src/gpu/effects/GrConvexPolyEffect.h |
+++ b/src/gpu/effects/GrConvexPolyEffect.h |
@@ -57,9 +57,10 @@ public: |
/** |
* Creates an effect that clips against the path. If the path is not a convex polygon, is |
* inverse filled, or has too many edges, this will return NULL. |
*/ |
- static GrEffectRef* Create(EdgeType, const SkPath&); |
+ static GrEffectRef* Create(EdgeType, const SkPath&, const SkVector* offset= NULL); |
virtual ~GrConvexPolyEffect(); |
@@ -57,9 +57,10 @@ public: |
/** |
* Creates an effect that clips against the path. If the path is not a convex polygon, is |
- * inverse filled, or has too many edges, this will return NULL. |
+ * inverse filled, or has too many edges, this will return NULL. If offset is non-NULL, then |
+ * the path is translated by the vector. |
*/ |